data_gen: Simulated data set generation

Description Usage Arguments Value Examples

View source: R/data_gen.R

Description

data_gen generates datasets in the simulation study.

Usage

1
2
3
4
5
6
7
8
9
data_gen(
  seed.cluster = 123,
  seed.data = 654,
  n,
  p,
  theta = 2,
  row_group = 4,
  col_group = 4
)

Arguments

seed.cluster

seed.cluster is used to control the cluster assignment

seed.data

seed.data is used to control the data generation given clustering structure

n

number of subjects

p

number of features

theta

the variance of the x, which is sampled from a normal distribution

row_group

number of row clusters

col_group

number of column clusters

Value

Output is the simulated dataset

Examples

1
2
set.seed(123)
data = data_gen(n = 100, p = 80)

sakuramomo1005/bi-ADMM documentation built on Dec. 22, 2021, 9:20 p.m.