Description Usage Arguments Value Examples
data_gen generates datasets in the simulation study.
1 2 3 4 5 6 7 8 9 | data_gen(
seed.cluster = 123,
seed.data = 654,
n,
p,
theta = 2,
row_group = 4,
col_group = 4
)
|
seed.cluster |
seed.cluster is used to control the cluster assignment |
seed.data |
seed.data is used to control the data generation given clustering structure |
n |
number of subjects |
p |
number of features |
theta |
the variance of the x, which is sampled from a normal distribution |
row_group |
number of row clusters |
col_group |
number of column clusters |
Output is the simulated dataset
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.